@@ -1,8 +1,8 @@
-# @(#)$Id: Informix.pm,v 1.2 1998/11/03 00:53:02 jleffler Exp $
+# @(#)$Id: Informix.pm,v 95.1 1999/11/18 22:10:59 jleffler Exp $
 
 package Bundle::DBD::Informix;
 
-$VERSION = '0.60';
+$VERSION = '0.95';
 
 1;
 
@@ -18,6 +18,8 @@ C<perl -MCPAN -e 'install Bundle::DBD::Informix'>
 
 =head1 CONTENTS
 
+Digest::MD5  - Perl interface to the MD5 Algorithm by GAAS (Gisle Aas)
+
 Bundle::DBI  - Bundle for DBI by TIMB (Tim Bunce)
 
 DBD::Informix  - DBD::Informix by JOHNL (Jonathan Leffler)
@@ -35,6 +37,14 @@ You could start by running:
 
     C<perl -MCPAN -e 'install Bundle::CPAN'>
 
+Note that DBD::Informix does not directly use Digest::MD5.  However, if
+Informix R&D or Tech Support takes over DBD::Informix (which, as of
+1999-11-17, they have not agreed to do), then you will be required to
+demonstrate that the MD5 checksums of the code you've got match the
+original, or you'll be required to provide the diffs between the original
+and what you are using.  The shell script md5.verify and Perl script
+md5.check will be used to do this.
+
 =head1 SEE ALSO
 
 Bundle::DBI
